@@ -23,6 +23,7 @@ Airflow connection of type `wasb` exists. Authorization can be done by supplying
 login (=Storage account name) and password (=KEY), or login and SAS token in the extra
 field (see connection `wasb_default` for an example).
 """
+
 from __future__ import annotations
 
 import logging
@@ -61,7 +62,7 @@ AsyncCredentials = Union[AsyncClientSecretCredential, AsyncDefaultAzureCredentia
 
 class WasbHook(BaseHook):
     """
-    Interacts with Azure Blob Storage through the ``wasb://`` protocol.
+    Interact with Azure Blob Storage through the ``wasb://`` protocol.
 
     These parameters have to be passed in Airflow Data Base: account_name and account_key.
 
@@ -84,7 +85,7 @@ class WasbHook(BaseHook):
     @classmethod
     @add_managed_identity_connection_widgets
     def get_connection_form_widgets(cls) -> dict[str, Any]:
-        """Returns connection widgets to add to connection form."""
+        """Return connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget, BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField, StringField
@@ -104,7 +105,7 @@ class WasbHook(BaseHook):
 
     @classmethod
     def get_ui_field_behaviour(cls) -> dict[str, Any]:
-        """Returns custom field behaviour."""
+        """Return custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port"],
             "relabeling": {
@@ -228,7 +229,7 @@ class WasbHook(BaseHook):
 
     def _get_container_client(self, container_name: str) -> ContainerClient:
         """
-        Instantiates a container client.
+        Instantiate a container client.
 
         :param container_name: The name of the container
         :return: ContainerClient
@@ -237,7 +238,7 @@ class WasbHook(BaseHook):
 
     def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient:
         """
-        Instantiates a blob client.
+        Instantiate a blob client.
 
         :param container_name: The name of the blob container
         :param blob_name: The name of the blob. This needs not be existing
@@ -412,7 +413,7 @@ class WasbHook(BaseHook):
         **kwargs,
     ) -> dict[str, Any]:
         """
-        Creates a new blob from a data source with automatic chunking.
+        Create a new blob from a data source with automatic chunking.
 
         :param container_name: The name of the container to upload data
         :param blob_name: The name of the blob to upload. This need not exist in the container
@@ -434,7 +435,7 @@ class WasbHook(BaseHook):
         self, container_name, blob_name, offset: int | None = None, length: int | None = None, **kwargs
     ) -> StorageStreamDownloader:
         """
-        Downloads a blob to the StorageStreamDownloader.
+        Download a blob to the StorageStreamDownloader.
 
         :param container_name: The name of the container containing the blob
         :param blob_name: The name of the blob to download
@@ -494,7 +495,7 @@ class WasbHook(BaseHook):
 
     def delete_blobs(self, container_name: str, *blobs, **kwargs) -> None:
         """
-        Marks the specified blobs or snapshots for deletion.
+        Mark the specified blobs or snapshots for deletion.
 
         :param container_name: The name of the container containing the blobs
         :param blobs: The blobs to delete. This can be a single blob, or multiple values
